@@ -4,7 +4,7 @@ sudo zypper -n install make git gcc python3-devel python3-setuptools \
     python3-numpy python3-numpy-devel python3-scipy python3-matplotlib \
     python3-qt5 python3-qt4 \
     python3-matplotlib-qt4 \
-    python3-PyYAML python3-progressbar python3-Jinja2 \
+    python3-PyYAML python3-Jinja2 \
     python3-requests \
     python3-nose python3-coverage
 
