@@ -703,7 +703,7 @@ on
                 'qssp had a non-zero exit state: %i' % proc.returncode)
         if error_str:
 
-            logger.warn(
+            logger.warning(
                 'qssp emitted something via stderr: \n\n%s'
                 % error_str.decode())
 
@@ -774,7 +774,7 @@ qssp has been invoked as "%s"'''.lstrip() % (
                 shutil.rmtree(self.tempdir)
                 self.tempdir = None
             else:
-                logger.warn(
+                logger.warning(
                     'not removing temporary directory: %s' % self.tempdir)
 
 
@@ -1053,7 +1053,7 @@ class QSSPGFBuilder(gf.builder.Builder):
 
                 finally:
                     if duplicate_inserts:
-                        logger.warn(
+                        logger.warning(
                             '%i insertions skipped (duplicates)'
                             % duplicate_inserts)
 
