@@ -4,9 +4,7 @@
 # ---|P------/S----------~Lg----------
 from __future__ import absolute_import
 
-import calendar
 import math
-import time
 import copy
 import logging
 import sys
@@ -59,7 +57,9 @@ g_color_b = [plot.color(x) for x in (
     'skyblue1', 'skyblue2', 'skyblue3',
     'orange1', 'orange2', 'orange3',
     'plum1', 'plum2', 'plum3',
-    'chocolate1', 'chocolate2', 'chocolate3')]
+    'chocolate1', 'chocolate2', 'chocolate3',
+    'butter1', 'butter2', 'butter3',
+    'aluminium3', 'aluminium4', 'aluminium5')]
 
 
 class MarkerParseError(Exception):
@@ -83,49 +83,6 @@ class Marker(object):
         (color-coded)
     '''
 
-    @staticmethod
-    def from_string(line):
-
-        def fail():
-            raise MarkerParseError(
-                'Unable to create marker from string: "%s"' % line)
-
-        def parsedate(ymd, hms, sfs):
-            return util.to_time_str(calendar.timegm(
-                time.strptime(ymd+' '+hms, '%Y-%m-%d %H:%M:%S'))) + float(sfs)
-
-        try:
-            toks = line.split()
-            if len(toks) in (4, 5):
-                tmin = parsedate(*toks[:3])
-                tmax = tmin
-
-            elif len(toks) in (8, 9):
-                tmin = parsedate(*toks[:3])
-                tmax = parsedate(*toks[3:6])
-
-            else:
-                fail()
-
-            if len(toks) in (5, 9):
-                kind = int(toks[-2])
-            else:
-                kind = int(toks[-1])
-
-            nslc_ids = []
-            if len(toks) in (5, 9):
-                for snslc in toks[-1].split(','):
-                    nslc = snslc.split('.')
-                    if len(nslc) != 4:
-                        fail()
-
-                    nslc_ids.append(tuple(nslc))
-
-        except MarkerParseError:
-            fail()
-
-        return Marker(nslc_ids, tmin, tmax, kind=kind)
-
     @staticmethod
     def save_markers(markers, fn, fdigits=3):
         '''
@@ -166,22 +123,7 @@ class Marker(object):
         with open(fn, 'r') as f:
             line = f.readline()
             if not line.startswith('# Snuffler Markers File Version'):
-                f.seek(0)
-                for iline, line in enumerate(f):
-                    line = str(line.decode('ascii'))
-                    sline = line.strip()
-                    if not sline or sline.startswith('#'):
-                        continue
-                    try:
-                        m = Marker.from_string(sline)
-                        markers.append(m)
-
-                    except MarkerParseError:
-                        logger.warning(
-                            'Invalid marker definition in line %i of file "%s"'
-                            % (iline+1, fn))
-
-                f.close()
+                raise MarkerParseError('Not a marker file')
 
             elif line.startswith('# Snuffler Markers File Version 0.2'):
                 reader = TableReader(f)
