@@ -7,7 +7,6 @@ Effective seismological trace viewer.
 '''
 from __future__ import absolute_import
 
-import os
 import sys
 import signal
 import logging
@@ -31,11 +30,60 @@ from pyrocko import io              # noqa
 
 from . import pile_viewer     # noqa
 
-from .qt_compat import qc, qg, qw, qn
+from .qt_compat import qc, qg, qw
 
 logger = logging.getLogger('pyrocko.gui.snuffler_app')
 
 
+class _Getch:
+    '''
+    Gets a single character from standard input.
+
+    Does not echo to the screen.
+
+    https://stackoverflow.com/questions/510357/how-to-read-a-single-character-from-the-user
+    '''
+    def __init__(self):
+        try:
+            self.impl = _GetchWindows()
+        except ImportError:
+            self.impl = _GetchUnix()
+
+    def __call__(self): return self.impl()
+
+
+class _GetchUnix:
+    def __init__(self):
+        import tty, sys  # noqa
+
+    def __call__(self):
+        import sys
+        import tty
+        import termios
+
+        fd = sys.stdin.fileno()
+        old_settings = termios.tcgetattr(fd)
+        try:
+            tty.setraw(fd)
+            ch = sys.stdin.read(1)
+        finally:
+            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
+
+        return ch
+
+
+class _GetchWindows:
+    def __init__(self):
+        import msvcrt  # noqa
+
+    def __call__(self):
+        import msvcrt
+        return msvcrt.getch()
+
+
+getch = _Getch()
+
+
 class AcquisitionThread(qc.QThread):
     def __init__(self, post_process_sleep=0.0):
         qc.QThread.__init__(self)
@@ -717,6 +765,12 @@ class SnufflerWindow(qw.QMainWindow):
         self.get_view().add_panel_toggler(mitem)
         self.dockwidget_to_toggler[dockwidget] = mitem
 
+        if pile_viewer.is_macos:
+            tabbars = self.findChildren(qw.QTabBar)
+            for tabbar in tabbars:
+                tabbar.setShape(qw.QTabBar.TriangularNorth)
+                tabbar.setDocumentMode(True)
+
     def toggle_panel(self, dockwidget, visible):
         if visible is None:
             visible = not dockwidget.isVisible()
@@ -778,7 +832,9 @@ class SnufflerWindow(qw.QMainWindow):
 class Snuffler(qw.QApplication):
 
     def __init__(self):
-        qw.QApplication.__init__(self, sys.argv)
+        qw.QApplication.__init__(self, [])
+        self.setApplicationName('Snuffler')
+        self.setApplicationDisplayName('Snuffler')
         self.lastWindowClosed.connect(self.myQuit)
         self.server = None
         self.loader = None
@@ -791,63 +847,17 @@ class Snuffler(qw.QApplication):
     def uninstall_sigint_handler(self):
         signal.signal(signal.SIGINT, self._old_signal_handler)
 
-    def start_server(self):
-        self.connections = []
-        s = qn.QTcpServer(self)
-        s.listen(qn.QHostAddress.LocalHost)
-        s.newConnection.connect(
-            self.handle_accept)
-        self.server = s
-
-    def start_loader(self):
-        self.loader = SimpleConnectionHandler(
-            self,
-            add_files=self.add_files,
-            update_progress=self.update_progress)
-        ticket = os.urandom(32)
-        self.forker.spawn('loader', self.server.serverPort(), ticket)
-        self.connection_handlers[ticket] = self.loader
-
-    def handle_accept(self):
-        sock = self.server.nextPendingConnection()
-        con = Connection(self, sock)
-        self.connections.append(con)
-
-        con.disconnected.connect(
-            self.handle_disconnected)
-
-        con.received.connect(
-            self.handle_received_ticket)
-
-    def handle_disconnected(self, connection):
-        self.connections.remove(connection)
-        connection.close()
-        del connection
-
-    def handle_received_ticket(self, connection, object):
-        if not isinstance(object, str):
-            self.handle_disconnected(connection)
-
-        ticket = object
-        if ticket in self.connection_handlers:
-            h = self.connection_handlers[ticket]
-            connection.received.disconnect(
-                self.handle_received_ticket)
-
-            h.set_connection(connection)
-        else:
-            self.handle_disconnected(connection)
-
     def snuffler_windows(self):
         return [w for w in self.topLevelWidgets()
                 if isinstance(w, SnufflerWindow) and not w.is_closing()]
 
     def event(self, e):
         if isinstance(e, qg.QFileOpenEvent):
-            paths = [str(e.file())]
-            wins = self.snuffler_windows()
-            if wins:
-                wins[0].get_view().load_soon(paths)
+            path = str(e.file())
+            if path != sys.argv[0]:
+                wins = self.snuffler_windows()
+                if wins:
+                    wins[0].get_view().load_soon([path])
 
             return True
         else:
@@ -860,16 +870,30 @@ class Snuffler(qw.QApplication):
         self.loader.ship(
             ('load', pathes, cachedirname, pattern, format))
 
-    def add_files(self, files):
-        p = self.pile_viewer.get_pile()
-        p.add_files(files)
-        self.pile_viewer.update_contents()
-
     def update_progress(self, task, percent):
         self.pile_viewer.progressbars.set_status(task, percent)
 
     def myCloseAllWindows(self, *args):
-        self.closeAllWindows()
+
+        def confirm():
+            try:
+                print('\nQuit Snuffler? [y/n]', file=sys.stderr)
+                confirmed = getch() == 'y'
+                if not confirmed:
+                    print('Continuing.', file=sys.stderr)
+                else:
+                    print('Quitting Snuffler.', file=sys.stderr)
+
+                return confirmed
+
+            except Exception:
+                return False
+
+        if confirm():
+            for win in self.snuffler_windows():
+                win.instant_close = True
+
+            self.closeAllWindows()
 
     def myQuit(self, *args):
         self.quit()
