@@ -22,9 +22,9 @@ from .qt_compat import qc, qw, getSaveFileName
 from pyrocko import pile, config
 from pyrocko.util import quote
 
-from .util import (ValControl, LinValControl, FigureFrame, WebKitFrame,
-                   VTKFrame, PixmapFrame, Marker, EventMarker, PhaseMarker,
-                   load_markers, save_markers)
+from .util import (ValControl, LinValControl, FigureFrame, SmartplotFrame,
+                   WebKitFrame, VTKFrame, PixmapFrame, Marker, EventMarker,
+                   PhaseMarker, load_markers, save_markers)
 
 
 from importlib import reload
@@ -176,7 +176,7 @@ class Snuffling(object):
         self._cli_params = {}
         self._filename = None
         self._force_panel = False
-        self._call_in_progress = False
+        self._call_in_progress = {}
 
     def setup(self):
         '''
@@ -452,7 +452,7 @@ class Snuffling(object):
         self.error(message)
         raise SnufflingCallFailed(message)
 
-    def pylab(self, name=None, get='axes'):
+    def pylab(self, name=None, get='axes', figure_cls=None):
         '''
         Create a :py:class:`FigureFrame` and return either the frame,
         a :py:class:`matplotlib.figure.Figure` instance or a
@@ -466,7 +466,7 @@ class Snuffling(object):
             self._iplot += 1
             name = 'Plot %i (%s)' % (self._iplot, self.get_name())
 
-        fframe = FigureFrame()
+        fframe = FigureFrame(figure_cls=figure_cls)
         self._panel_parent.add_tab(name, fframe)
         if get == 'axes':
             return fframe.gca()
@@ -495,14 +495,33 @@ class Snuffling(object):
 
         return self.pylab(name=name, get='axes')
 
-    def figure_frame(self, name=None):
+    def figure_frame(self, name=None, figure_cls=None):
         '''
         Create a :py:class:`pyrocko.gui.util.FigureFrame`.
 
         :param name: labels the tab figure frame
         '''
 
-        return self.pylab(name=name, get='figure_frame')
+        return self.pylab(name=name, get='figure_frame', figure_cls=figure_cls)
+
+    def smartplot_frame(self, name, *args, plot_cls=None, **kwargs):
+        '''
+        Create a :py:class:`pyrocko.gui.util.SmartplotFrame`.
+
+        :param name: labels the tab
+        :param *args, **kwargs:
+            passed to :py:class:`pyrocko.plot.smartplot.Plot`
+        :param plot_cls:
+            if given, subclass to be used instead of
+            :py:class:`pyrocko.plot.smartplot.Plot`
+        '''
+        frame = SmartplotFrame(
+            plot_args=args,
+            plot_cls=plot_cls,
+            plot_kwargs=kwargs)
+
+        self._panel_parent.add_tab(name, frame)
+        return frame
 
     def pixmap_frame(self, filename=None, name=None):
         '''
@@ -1310,15 +1329,7 @@ class Snuffling(object):
 
                 def call_and_update(method):
                     def f():
-                        try:
-                            method()
-                        except SnufflingError as e:
-                            if not isinstance(e, SnufflingCallFailed):
-                                # those have logged within error()
-                                logger.error('%s: %s' % (self._name, e))
-                            logger.error(
-                                '%s: Snuffling action failed' % self._name)
-
+                        self.check_call(method)
                         self.get_viewer().update()
                     return f
 
@@ -1469,7 +1480,7 @@ class Snuffling(object):
         param = self.get_parameters()[iparam]
         self._set_parameter_value(param.ident, value)
         if self._live_update:
-            self.check_call()
+            self.check_call(self.call)
             self.get_viewer().update()
 
     def switch_on_snuffling_panel(self, ident, state):
@@ -1479,7 +1490,7 @@ class Snuffling(object):
 
         self._set_parameter_value(ident, state)
         if self._live_update:
-            self.check_call()
+            self.check_call(self.call)
             self.get_viewer().update()
 
     def choose_on_snuffling_panel(self, ident, state):
@@ -1489,7 +1500,7 @@ class Snuffling(object):
 
         self._set_parameter_value(ident, state)
         if self._live_update:
-            self.check_call()
+            self.check_call(self.call)
             self.get_viewer().update()
 
     def menuitem_triggered(self, arg):
@@ -1500,7 +1511,7 @@ class Snuffling(object):
         and triggers an update on the viewer widget.
         '''
 
-        self.check_call()
+        self.check_call(self.call)
 
         if self._have_pre_process_hook:
             self._pre_process_hook_enabled = arg
@@ -1521,7 +1532,7 @@ class Snuffling(object):
         and triggers an update on the viewer widget.
         '''
 
-        self.check_call()
+        self.check_call(self.call)
         self.get_viewer().update()
 
     def clear_button_triggered(self):
@@ -1662,15 +1673,15 @@ class Snuffling(object):
         self._tickets = []
         self._markers = []
 
-    def check_call(self):
+    def check_call(self, method):
 
-        if self._call_in_progress:
+        if method in self._call_in_progress:
             self.show_message('error', 'Previous action still in progress.')
             return
 
         try:
-            self._call_in_progress = True
-            self.call()
+            self._call_in_progress[method] = True
+            method()
             return 0
 
         except SnufflingError as e:
@@ -1688,7 +1699,7 @@ class Snuffling(object):
             self.show_message('error', message)
 
         finally:
-            self._call_in_progress = False
+            del self._call_in_progress[method]
 
     def call(self):
         '''
