@@ -882,10 +882,8 @@ def beautify_axes(axes):
 
 class FigureFrame(qw.QFrame):
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, figure_cls=None):
         qw.QFrame.__init__(self, parent)
-
-        # bgrgb = self.palette().color(qw.QPalette.Window).getRgb()[:3]
         fgcolor = plot.tango_colors['aluminium5']
         dpi = 0.5*(self.logicalDpiX() + self.logicalDpiY())
 
@@ -953,7 +951,9 @@ class FigureFrame(qw.QFrame):
         except KeyError:
             pass
 
-        from matplotlib.figure import Figure
+        if figure_cls is None:
+            from matplotlib.figure import Figure
+            figure_cls = Figure
 
         from matplotlib.backends.backend_qt5agg import \
             NavigationToolbar2QT as NavigationToolbar
@@ -966,12 +966,22 @@ class FigureFrame(qw.QFrame):
         layout.setSpacing(0)
 
         self.setLayout(layout)
-        self.figure = Figure(dpi=dpi)
+        self.figure = figure_cls(dpi=dpi)
         self.canvas = FigureCanvas(self.figure)
         self.canvas.setParent(self)
+        self.canvas.setSizePolicy(
+            qw.QSizePolicy(
+                qw.QSizePolicy.Expanding,
+                qw.QSizePolicy.Expanding))
+        toolbar_frame = qw.QFrame()
+        toolbar_frame.setFrameShape(qw.QFrame.StyledPanel)
+        toolbar_frame_layout = qw.QHBoxLayout()
+        toolbar_frame_layout.setContentsMargins(0, 0, 0, 0)
+        toolbar_frame.setLayout(toolbar_frame_layout)
         self.toolbar = NavigationToolbar(self.canvas, self)
-        layout.addWidget(self.toolbar, 0, 0)
-        layout.addWidget(self.canvas, 1, 0)
+        layout.addWidget(self.canvas, 0, 0)
+        toolbar_frame_layout.addWidget(self.toolbar)
+        layout.addWidget(toolbar_frame, 1, 0)
         self.closed = False
 
     def gca(self):
@@ -992,6 +1002,27 @@ class FigureFrame(qw.QFrame):
         self.closed = True
 
 
+class SmartplotFrame(FigureFrame):
+    def __init__(
+            self, parent=None, plot_args=[], plot_kwargs={}, plot_cls=None):
+
+        from pyrocko.plot import smartplot
+
+        FigureFrame.__init__(
+            self,
+            parent=parent,
+            figure_cls=smartplot.SmartplotFigure)
+
+        if plot_cls is None:
+            plot_cls = smartplot.Plot
+
+        self.plot = plot_cls(
+            *plot_args,
+            fig=self.figure,
+            call_mpl_init=False,
+            **plot_kwargs)
+
+
 class WebKitFrame(qw.QFrame):
 
     def __init__(self, url=None, parent=None):
