@@ -7,6 +7,7 @@ from __future__ import division, absolute_import
 from struct import unpack
 import os
 import re
+import math
 import logging
 
 from pyrocko import trace
@@ -15,6 +16,7 @@ from .io_common import FileLoadError, FileSaveError
 
 logger = logging.getLogger('pyrocko.io.mseed')
 
+MSEED_HEADER_BYTES = 64
 VALID_RECORD_LENGTHS = tuple(2**exp for exp in range(8, 20))
 
 
@@ -22,30 +24,55 @@ class CodeTooLong(FileSaveError):
     pass
 
 
-def iload(filename, load_data=True):
+def iload(filename, load_data=True, offset=0, segment_size=0, nsegments=0):
     from pyrocko import mseed_ext
 
     have_zero_rate_traces = False
     try:
-        traces = []
-        for tr in mseed_ext.get_traces(filename, load_data):
-            network, station, location, channel = tr[1:5]
-            tmin = float(tr[5])/float(mseed_ext.HPTMODULUS)
-            tmax = float(tr[6])/float(mseed_ext.HPTMODULUS)
-            try:
-                deltat = reuse(1.0/float(tr[7]))
-            except ZeroDivisionError:
-                have_zero_rate_traces = True
-                continue
+        isegment = 0
+        while isegment < nsegments or nsegments == 0:
+            tr_tuples = mseed_ext.get_traces(
+                filename, load_data, offset, segment_size)
 
-            ydata = tr[8]
+            if not tr_tuples:
+                break
 
-            traces.append(trace.Trace(
-                network, station, location, channel, tmin, tmax,
-                deltat, ydata))
+            for tr_tuple in tr_tuples:
+                network, station, location, channel = tr_tuple[1:5]
+                tmin = float(tr_tuple[5])/float(mseed_ext.HPTMODULUS)
+                tmax = float(tr_tuple[6])/float(mseed_ext.HPTMODULUS)
+                try:
+                    deltat = reuse(1.0/float(tr_tuple[7]))
+                except ZeroDivisionError:
+                    have_zero_rate_traces = True
+                    continue
 
-        for tr in traces:
-            yield tr
+                ydata = tr_tuple[8]
+
+                tr = trace.Trace(
+                    network.strip(),
+                    station.strip(),
+                    location.strip(),
+                    channel.strip(),
+                    tmin,
+                    tmax,
+                    deltat,
+                    ydata)
+
+                tr.meta = {
+                    'offset_start': offset,
+                    'offset_end': tr_tuple[9],
+                    'last': tr_tuple[10],
+                    'segment_size': segment_size
+                }
+
+                yield tr
+
+            if tr_tuple[10]:
+                break
+
+            offset = tr_tuple[9]
+            isegment += 1
 
     except (OSError, mseed_ext.MSeedError) as e:
         raise FileLoadError(str(e)+' (file: %s)' % filename)
@@ -56,20 +83,22 @@ def iload(filename, load_data=True):
             '(maybe LOG traces)' % filename)
 
 
-def as_tuple(tr):
+def as_tuple(tr, dataquality='D'):
     from pyrocko import mseed_ext
     itmin = int(round(tr.tmin*mseed_ext.HPTMODULUS))
     itmax = int(round(tr.tmax*mseed_ext.HPTMODULUS))
     srate = 1.0/tr.deltat
     return (tr.network, tr.station, tr.location, tr.channel,
-            itmin, itmax, srate, tr.get_ydata())
+            itmin, itmax, srate, dataquality, tr.get_ydata())
 
 
 def save(traces, filename_template, additional={}, overwrite=True,
-         steim=1, record_length=4096):
+         dataquality='D', record_length=4096, append=False, steim=1):
     from pyrocko import mseed_ext
 
     assert record_length in VALID_RECORD_LENGTHS
+    assert dataquality in ('D', 'E', 'C', 'O', 'T', 'L'), 'invalid dataquality'
+    overwrite = True if append else overwrite
 
     fn_tr = {}
     for tr in traces:
@@ -96,12 +125,11 @@ def save(traces, filename_template, additional={}, overwrite=True,
         trtups = []
         traces_thisfile.sort(key=lambda a: a.full_id)
         for tr in traces_thisfile:
-            trtups.append(as_tuple(tr))
+            trtups.append(as_tuple(tr, dataquality))
 
         ensuredirs(fn)
         try:
-            mseed_ext.store_traces(
-                trtups, fn, record_length=record_length, steim=steim)
+            mseed_ext.store_traces(trtups, fn, record_length, append, steim)
         except mseed_ext.MSeedError as e:
             raise FileSaveError(
                 str(e) + ' (while storing traces to file \'%s\')' % fn)
@@ -112,6 +140,33 @@ def save(traces, filename_template, additional={}, overwrite=True,
 tcs = {}
 
 
+def get_bytes(traces, dataquality='D', record_length=4096, steim=1):
+    from pyrocko import mseed_ext
+
+    assert record_length in VALID_RECORD_LENGTHS
+    assert dataquality in ('D', 'E', 'C', 'O', 'T', 'L'), 'invalid dataquality'
+
+    nbytes_approx = 0
+    rl = record_length
+    trtups = []
+    for tr in traces:
+        for code, maxlen, val in zip(
+                ['network', 'station', 'location', 'channel'],
+                [2, 5, 2, 3],
+                tr.nslc_id):
+
+            if len(val) > maxlen:
+                raise CodeTooLong(
+                    '%s code too long to be stored in MSeed file: %s' %
+                    (code, val))
+
+        nbytes_approx += math.ceil(
+            tr.ydata.nbytes / (rl-MSEED_HEADER_BYTES)) * rl
+        trtups.append(as_tuple(tr, dataquality))
+
+    return mseed_ext.mseed_bytes(trtups, nbytes_approx, record_length, steim)
+
+
 def detect(first512):
 
     if len(first512) < 256:
