@@ -264,22 +264,15 @@ iqb1 iqb2 iqbx iqmt ieq ieq1 ieq2 ime iex inu inc io_ il ir it iu
             hv = list(struct.unpack(format, filedata[:nbn]))
 
             strings = str(filedata[nbn:nbh].decode('ascii'))
-            hv.append(strings[:8].rstrip())
-            hv.append(strings[8:24].rstrip())
+            hv.append(strings[:8].rstrip(' \x00'))
+            hv.append(strings[8:24].rstrip(' \x00'))
             for i in range(len(strings[24:])//8):
-                hv.append(strings[24+i*8:24+(i+1)*8].rstrip())
+                hv.append(strings[24+i*8:24+(i+1)*8].rstrip(' \x00'))
 
             self.header_vals = hv
             for k, v in zip(SacFile.header_keys, self.header_vals):
                 vn = self.val_or_none(k, v)
-                if isinstance(vn, str):
-                    ipos = vn.find('\x00')
-                    if ipos != -1:
-                        vn = vn[:ipos]
-
-                    self.__dict__[k] = vn.rstrip()
-                else:
-                    self.__dict__[k] = vn
+                self.__dict__[k] = vn
 
             if self.leven == -12345:
                 self.leven = True
@@ -311,7 +304,7 @@ iqb1 iqb2 iqbx iqmt ieq ieq1 ieq2 ime iex inu inc io_ il ir it iu
                 else:
                     dtype = num.dtype('<f4')
 
-                self.data.append(num.array(num.fromstring(
+                self.data.append(num.array(num.frombuffer(
                     filedata[nbh+iblock*nbb:nbh+(iblock+1)*nbb],
                     dtype=dtype),
                     dtype=float))
@@ -360,7 +353,7 @@ iqb1 iqb2 iqbx iqmt ieq ieq1 ieq2 ime iex inu inc io_ il ir it iu
         with open(filename, 'wb') as f:
             f.write(header_data)
             for fdata in self.data:
-                f.write(fdata.astype(num.float32).tostring())
+                f.write(fdata.astype(num.float32).tobytes())
 
     def __str__(self):
         str = ''
