@@ -46,6 +46,42 @@ conversion = {
     ('M/S**2', 'M/S**2'): None}
 
 
+unit_to_quantity = {
+    'M/S': 'velocity',
+    'M': 'displacement',
+    'M/S**2': 'acceleration',
+    'V': 'voltage',
+    'COUNTS': 'counts',
+    'COUNT': 'counts',
+    'PA': 'pressure',
+    'RAD': 'rotation-displacement',
+    'R': 'rotation-displacement',
+    'RAD/S': 'rotation-velocity',
+    'R/S': 'rotation-velocity',
+    'RAD/S**2': 'rotation-acceleration',
+    'R/S**2': 'rotation-acceleration'}
+
+
+def to_quantity(unit, context, delivery):
+
+    if unit is None:
+        return None
+
+    name = unit.name.upper()
+    if name in unit_to_quantity:
+        return unit_to_quantity[name]
+    else:
+        delivery.log.append((
+            'warning',
+            'Units not supported by Squirrel framework: %s' % (
+                unit.name.upper() + (
+                    ' (%s)' % unit.description
+                    if unit.description else '')),
+            context))
+
+        return 'unsupported_quantity(%s)' % unit
+
+
 class StationXMLError(Exception):
     pass
 
@@ -241,7 +277,33 @@ def tts(t):
     if t is None:
         return '?'
     else:
-        return util.tts(t, format='%Y-%m-%d')
+        return util.tts(t, format='%Y-%m-%d %H:%M:%S')
+
+
+def le_open_left(a, b):
+    return a is None or (b is not None and a <= b)
+
+
+def le_open_right(a, b):
+    return b is None or (a is not None and a <= b)
+
+
+def eq_open(a, b):
+    return (a is None and b is None) \
+        or (a is not None and b is not None and a == b)
+
+
+def contains(a, b):
+    return le_open_left(a.start_date, b.start_date) \
+        and le_open_right(b.end_date, a.end_date)
+
+
+def find_containing(candidates, node):
+    for candidate in candidates:
+        if contains(candidate, node):
+            return candidate
+
+    return None
 
 
 this_year = time.gmtime()[0]
@@ -1113,37 +1175,9 @@ class ResponseStage(Object):
         delivery_pr.log = []
         elements = delivery.extend_without_payload(delivery_pr)
 
-        def to_quantity(unit):
-            trans = {
-                'M/S': 'velocity',
-                'M': 'displacement',
-                'M/S**2': 'acceleration',
-                'V': 'voltage',
-                'COUNTS': 'counts',
-                'COUNT': 'counts',
-                'PA': 'pressure',
-                'RAD/S': 'rotation'}
-
-            if unit is None:
-                return None
-
-            name = unit.name.upper()
-            if name in trans:
-                return trans[name]
-            else:
-                delivery.log.append((
-                    'warning',
-                    'Units not supported by Squirrel framework: %s' % (
-                        unit.name.upper() + (
-                            ' (%s)' % unit.description
-                            if unit.description else '')),
-                    context))
-
-                return 'unsupported_quantity(%s)' % unit
-
         delivery.payload = [ResponseStage(
-            input_quantity=to_quantity(self.input_units),
-            output_quantity=to_quantity(self.output_units),
+            input_quantity=to_quantity(self.input_units, context, delivery),
+            output_quantity=to_quantity(self.output_units, context, delivery),
             input_sample_rate=self.input_sample_rate,
             output_sample_rate=self.output_sample_rate,
             elements=elements,
@@ -1431,6 +1465,18 @@ class Response(Object):
                 checkpoints.extend(delivery.extend_without_payload(
                     self._sensitivity_checkpoints(all_responses, context)))
 
+            sq_stages = delivery.payload
+            if sq_stages:
+                if sq_stages[0].input_quantity is None \
+                        and self.instrument_sensitivity is not None:
+
+                    sq_stages[0].input_quantity = to_quantity(
+                        self.instrument_sensitivity.input_units,
+                        context, delivery)
+                    sq_stages[-1].output_quantity = to_quantity(
+                        self.instrument_sensitivity.output_units,
+                        context, delivery)
+
             sq_stages = delivery.expect()
 
             return Response(
@@ -1600,6 +1646,22 @@ def overlaps(a, b):
     )
 
 
+def check_overlaps(node_type_name, codes, nodes):
+    errors = []
+    for ia, a in enumerate(nodes):
+        for b in nodes[ia+1:]:
+            if overlaps(a, b):
+                errors.append(
+                    '%s epochs overlap for %s:\n'
+                    '    %s - %s\n    %s - %s' % (
+                        node_type_name,
+                        '.'.join(codes),
+                        tts(a.start_date), tts(a.end_date),
+                        tts(b.start_date), tts(b.end_date)))
+
+    return errors
+
+
 class Channel(BaseNode):
     '''
     Equivalent to SEED blockette 52 and parent element for the related the
@@ -2245,15 +2307,8 @@ class FDSNStationXML(Object):
 
         errors = []
         for nslc, channels in by_nslc.items():
-            for ia, a in enumerate(channels):
-                for b in channels[ia+1:]:
-                    if overlaps(a, b):
-                        errors.append(
-                            'Channel epochs overlap for %s:\n'
-                            '    %s - %s\n    %s - %s' % (
-                                '.'.join(nslc),
-                                tts(a.start_date), tts(a.end_date),
-                                tts(b.start_date), tts(b.end_date)))
+            errors.extend(check_overlaps('Channel', nslc, channels))
+
         return errors
 
     def check(self):
