@@ -79,7 +79,7 @@ units_dict = {
     'cm': cm,
 }
 
-_doc_units = "``'points'``, ``'inch'``, or ``'cm'``"
+_doc_units = "``'point'``, ``'inch'``, or ``'cm'``"
 
 
 def apply_units(x, units):
@@ -708,7 +708,7 @@ def nice_time_tick_inc(tinc_approx):
 
     elif tinc_approx >= 1.0:
         nice = [
-            1., 2., 5., 10., 20, 30, 60., 120., 300., 600., 1200., 1800.,
+            1., 2., 5., 10., 20., 30., 60., 120., 300., 600., 1200., 1800.,
             1*hours, 2*hours, 3*hours, 6*hours, 12*hours, days, 2*days]
 
         for tinc in nice:
@@ -820,3 +820,64 @@ def time_tick_labels(tmin, tmax, tinc, tinc_unit):
             times[0:0] = [tmin]
 
     return times, labels
+
+
+def mpl_time_axis(axes, approx_ticks=5.):
+
+    '''
+    Configure x axis of a matplotlib axes object for interactive time display.
+
+    :param axes: Axes to be configured.
+    :type axes: :py:class:`matplotlib.axes.Axes`
+
+    :param approx_ticks: Approximate number of ticks to create.
+    :type approx_ticks: float
+
+    This function tries to use nice tick increments and tick labels for time
+    ranges from microseconds to years, similar to how this is handled in
+    Snuffler.
+    '''
+
+    from matplotlib.ticker import Locator, Formatter
+
+    class labeled_float(float):
+        pass
+
+    class TimeLocator(Locator):
+
+        def __init__(self, approx_ticks=5.):
+            self._approx_ticks = approx_ticks
+            Locator.__init__(self)
+
+        def __call__(self):
+            vmin, vmax = self.axis.get_view_interval()
+            return self.tick_values(vmin, vmax)
+
+        def tick_values(self, vmin, vmax):
+            if vmax < vmin:
+                vmin, vmax = vmax, vmin
+
+            if vmin == vmax:
+                return []
+
+            tinc_approx = (vmax - vmin) / self._approx_ticks
+            tinc, tinc_unit = nice_time_tick_inc(tinc_approx)
+            times, labels = time_tick_labels(vmin, vmax, tinc, tinc_unit)
+            ftimes = []
+            for t, label in zip(times, labels):
+                ftime = labeled_float(t)
+                ftime._mpl_label = label
+                ftimes.append(ftime)
+
+            return self.raise_if_exceeds(ftimes)
+
+    class TimeFormatter(Formatter):
+
+        def __call__(self, x, pos=None):
+            if isinstance(x, labeled_float):
+                return x._mpl_label
+            else:
+                return time_to_str(x, format='%Y-%m-%d %H:%M:%S.6FRAC')
+
+    axes.xaxis.set_major_locator(TimeLocator(approx_ticks=approx_ticks))
+    axes.xaxis.set_major_formatter(TimeFormatter())
