@@ -33,6 +33,7 @@ QUANTITY_LABEL = {
 def get_azimuthal_targets(
         store_id, source, radius,
         azi_begin=0., azi_end=360., dazi=1.,
+        depth=0.0,
         interpolation='multilinear',
         components='RTZ', quantity='displacement'):
 
@@ -54,7 +55,7 @@ def get_azimuthal_targets(
         assert comp in dips.keys()
 
     target_kwargs = dict(
-        quantity='displacement',
+        quantity=quantity,
         interpolation=interpolation,
         store_id=store_id)
 
@@ -64,6 +65,7 @@ def get_azimuthal_targets(
             lon=source.lon,
             north_shift=coords[0, iazi] + source.north_shift,
             east_shift=coords[1, iazi] + source.east_shift,
+            depth=depth,
             azimuth={
                 'R': azi,
                 'T': azi+90.,
@@ -98,12 +100,11 @@ def get_seismogram_array(
         assert hasattr(target, 'azimuth')
         assert target.dazi
 
-        if fmin and fmax:
-            tr.bandpass(2, fmin, fmax)
-        elif fmin:
-            tr.highpass(4, fmin)
-        elif fmax:
-            tr.lowpass(4, fmax)
+        if fmin is not None:
+            tr.highpass(4, fmin, demean=False)
+
+        if fmax is not None:
+            tr.lowpass(4, fmax, demean=False)
 
         tmin = min(tmin, tr.tmin) if tmin else tr.tmin
         tmax = max(tmax, tr.tmax) if tmax else tr.tmax
@@ -112,10 +113,9 @@ def get_seismogram_array(
     for tr in traces:
         tr.extend(tmin, tmax, fillmethod='repeat')
         if envelope:
-            tr.abshilbert()
+            tr.envelope()
 
     data = num.array([tr.get_ydata() for tr in traces])
-    data -= data.mean()
     nsamples = data.shape[1]
     return data, num.linspace(tmin, tmax, nsamples)
 
@@ -179,6 +179,8 @@ def plot_directivity(
         distance=300*km, azi_begin=0., azi_end=360., dazi=1.,
         phases={'P': 'first{stored:any_P}-10%',
                 'S': 'last{stored:any_S}+50'},
+        interpolation='multilinear',
+        target_depth=0.0,
         quantity='displacement', envelope=False,
         component='R', fmin=0.01, fmax=0.1,
         hillshade=True, cmap=None,
@@ -206,13 +208,12 @@ def plot_directivity(
     :type azi_end: float
     :param dazi: Delta azimuth, bin size [deg]
     :type dazi: float
-    :param phase_begin: Start time of the window
-    :type phase_begin: :py:class:`~pyrocko.gf.meta.Timing`
-    :param phase_end: End time of the window
-    :type phase_end: :py:class:`~pyrocko.gf.meta.Timing`
+    :param phases: Phases to define start and end of time window
+    :type phases: :py:class:`dict` with :py:class:`str` keys and
+        :py:class:`~pyrocko.gf.meta.Timing` values
     :param quantity: Seismogram quantity, default ``displacement``
     :type quantity: str
-    :param envelope: Plot envelop instead of seismic trace
+    :param envelope: Plot envelope instead of seismic trace
     :type envelope: bool
     :param component: Forward modelled component, default ``R``. Choose from
         `RTZ`
@@ -223,7 +224,7 @@ def plot_directivity(
     :type fmax: float
     :param hillshade: Enable hillshading, default ``True``
     :type hillshade: bool
-    :param cmap: Matplotlit colormap to use, default ``seismic``.
+    :param cmap: Matplotlib colormap to use, default ``seismic``.
         When ``envelope`` is ``True`` the default colormap will be ``Reds``.
     :type cmap: str
     :param plot_mt: Plot a centered moment tensor, default ``full``.
@@ -231,7 +232,7 @@ def plot_directivity(
     :type plot_mt: str, bool
     :param show_phases: Show annotations, default ``True``
     :type show_phases: bool
-    :param show_description: Show desciption, default ``True``
+    :param show_description: Show description, default ``True``
     :type show_description: bool
     :param reverse_time: Reverse time axis. First phases arrive at the center,
         default ``False``
@@ -260,6 +261,8 @@ def plot_directivity(
 
     targets, azimuths = get_azimuthal_targets(
         store_id, source, distance, azi_begin, azi_end, dazi,
+        depth=target_depth,
+        interpolation=interpolation,
         components='R', quantity=quantity)
     ref_target = targets[0]
     store = engine.get_store(store_id)
@@ -318,9 +321,9 @@ def plot_directivity(
         strike_label = source.strike
 
     try:
-        ax.set_rlabel_position(strike_label % 180.)
+        ax.set_rlabel_position(strike_label % 180. - 180.)
     except AttributeError:
-        logger.warn('Old matplotlib version: cannot set label positions')
+        logger.warning('Old matplotlib version: cannot set label positions')
 
     def r_fmt(v, p):
         if v < tbegin or v > tend:
@@ -366,7 +369,7 @@ def plot_directivity(
 
     mesh = ax.pcolormesh(
         azimuths * d2r, times, data,
-        cmap=cmw.cmap, shading='gouraud', zorder=0)
+        cmap=cmw.cmap, norm=cmw.norm, shading='gouraud', zorder=0)
 
     if hillshade:
         mesh.update_scalarmappable()
