@@ -6,7 +6,7 @@ from __future__ import absolute_import, division, print_function
 
 import numpy as num
 from pyrocko import model
-from pyrocko.guts import Int, String, List
+from pyrocko.guts import Int, String, List, Float, Bool
 
 from pyrocko.model.station import load_stations
 from pyrocko.io import stationxml
@@ -16,13 +16,32 @@ from pyrocko.orthodrome import distance_accurate50m_numpy, \
 from .base import LocationGenerator
 
 guts_prefix = 'pf.scenario'
+km = 1e3
+d2r = num.pi / 180.
 
 
 class StationGenerator(LocationGenerator):
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._stations = None
+
     def get_stations(self):
         raise NotImplementedError
 
+    @property
+    def nstations(self):
+        return len(self.get_stations())
+
+    def has_stations(self):
+        if not self.get_stations():
+            return False
+        return True
+
+    def clear(self):
+        super().clear()
+        self._stations = None
+
     def get_distance_range(self, sources):
         dists = []
         for source in sources:
@@ -49,19 +68,10 @@ class ImportStationGenerator(StationGenerator):
         optional=True,
         help='List of files with station coordinates in StationXML format.')
 
-    pyrocko_stations = List.T(
+    stations = List.T(
         model.Station.T(),
         optional=True,
-        help='List of Pyrocko stations')
-
-    def __init__(self, **kwargs):
-        StationGenerator.__init__(self, **kwargs)
-        self._stations = None
-
-    def has_stations(self):
-        if not self.get_stations():
-            return False
-        return True
+        help='List of Pyrocko stations.')
 
     def get_center_latlon(self):
         stations = self.get_stations()
@@ -99,8 +109,8 @@ class ImportStationGenerator(StationGenerator):
                     stations.extend(
                         sxml.get_pyrocko_stations())
 
-            if self.pyrocko_stations:
-                stations.extend(self.pyrocko_stations)
+            if self.stations:
+                stations.extend(self.stations)
 
             self._stations = stations
 
@@ -110,12 +120,83 @@ class ImportStationGenerator(StationGenerator):
         stations = self.get_stations()
         return stations[istation].nsl()
 
-    def clear(self):
-        self._stations = None
 
-    @property
-    def nstations(self):
-        return len(self.get_stations())
+class CircleStationGenerator(StationGenerator):
+
+    radius = Float.T(
+        default=100*km,
+        help='Radius of the station circle in km.')
+
+    azi_start = Float.T(
+        default=0.,
+        help='Start azimuth of circle [deg]. '
+             'Default is a full circle, 0 - 360 deg')
+
+    azi_end = Float.T(
+        default=360.,
+        help='End azimuth of circle [deg]. '
+             'Default is a full circle, 0 - 360 deg')
+
+    nstations = Int.T(
+        default=10,
+        help='Number of evenly spaced stations.')
+
+    network_name = String.T(
+        default='CI',
+        help='Network name.')
+
+    channels = List.T(
+        default=['BHE', 'BHN', 'BHZ'],
+        help='Seismic channels to generate. Default: BHN, BHE, BHZ.')
+
+    shift_circle = Bool.T(
+        default=False,
+        help='Rotate circle away by half a station distance.')
+
+    def get_stations(self):
+        if self._stations is None:
+            if self.channels:
+                channels = [model.station.Channel(c) for c in self.channels]
+            else:
+                channels = None
+
+            azimuths = num.linspace(
+                self.azi_start*d2r, self.azi_end*d2r,
+                self.nstations, endpoint=False)
+
+            if self.shift_circle:
+                swath = (self.azi_end - self.azi_start)*d2r
+                azimuths += swath / self.nstations / 2.
+
+            lat, lon = self.get_center_latlon()
+
+            stations = []
+            for istation, azi in enumerate(azimuths):
+                net, sta, loc = self.nsl(istation)
+
+                station = model.Station(
+                    net, sta, loc,
+                    lat=lat,
+                    lon=lon,
+                    north_shift=num.cos(azi) * self.radius,
+                    east_shift=num.sin(azi) * self.radius,
+                    channels=channels)
+
+                stations.append(station)
+
+            self._stations = stations
+
+        return self._stations
+
+    def nsl(self, istation):
+        return self.network_name, 'S%03i' % (istation + 1), ''
+
+    def get_radius(self):
+        return self.radius
+
+    def clear(self):
+        super().clear()
+        self._stations = None
 
 
 class RandomStationGenerator(StationGenerator):
@@ -133,14 +214,6 @@ class RandomStationGenerator(StationGenerator):
         default=['BHE', 'BHN', 'BHZ'],
         help='Seismic channels to generate. Default: BHN, BHE, BHZ')
 
-    def __init__(self, **kwargs):
-        StationGenerator.__init__(self, **kwargs)
-        self._stations = None
-
-    def clear(self):
-        StationGenerator.clear(self)
-        self._stations = None
-
     def nsl(self, istation):
         return self.network_name, 'S%03i' % (istation + 1), '',
 
