@@ -5,24 +5,27 @@
 from __future__ import absolute_import, division, print_function
 
 import numpy as num
+from pyrocko import util
 from ..base import Generator
 
 
 class TargetGenerator(Generator):
 
     def get_time_range(self, sources):
-        ''' Get the target's time range.
+        '''
+        Get the target's time range.
 
         In the easiest case this is the sources' time range, yet for waveform
         targets we have to consider vmin, vmax
         '''
         times = num.array([source.time for source in sources],
-                          dtype=num.float)
+                          dtype=util.get_time_dtype())
 
         return num.min(times), num.max(times)
 
     def get_targets(self):
-        ''' Returns a list of targets, used class-internally to forward model.
+        '''
+        Returns a list of targets, used class-internally to forward model.
         '''
         return []
 
