@@ -559,8 +559,8 @@ class FDSNSource(Source, has_paths.HasPaths):
         def sgaps(nut):
             for tmin, tmax in gaps(
                     codes_to_avail[nut.codes],
-                    ctmin if ctmin is not None else nut.tmin,
-                    ctmax if ctmax is not None else nut.tmax):
+                    max(ctmin, nut.tmin) if ctmin is not None else nut.tmin,
+                    min(ctmax, nut.tmax) if ctmax is not None else nut.tmax):
 
                 subnut = clone(nut)
                 subnut.tmin = tmin
@@ -823,10 +823,12 @@ class FDSNSource(Source, has_paths.HasPaths):
 
             self._log_responses(
                 '%s: %s' % (
-                    k, codes_to_str_abbreviated(status[k])),
+                    k, codes_to_str_abbreviated(
+                        CodesNSLCE(tup) for tup in status[k])),
                 target=log_target)
 
-        squirrel.add(fns, kinds=['response'])
+        if fns:
+            squirrel.add(fns, kinds=['response'])
 
 
 __all__ = [
