@@ -43,10 +43,12 @@ def wrap(s):
     lines = []
     parts = re.split(r'\n{2,}', s)
     for part in parts:
-        if part.startswith('usage:'):
-            lines.extend(part.splitlines())
+        plines = part.splitlines()
+        if part.startswith('usage:') \
+                or all(line.startswith('    ') for line in plines):
+            lines.extend(plines)
         else:
-            for line in part.splitlines():
+            for line in plines:
                 if not line:
                     lines.append(line)
                 if not line.startswith(' '):
@@ -295,8 +297,8 @@ class SquirrelArgumentParser(PyrockoArgumentParser):
         :py:class:`~pyrocko.squirrel.base.Squirrel` instance.
 
         This will  optional arguments ``--add``, ``--include``, ``--exclude``,
-        ``--optimistic``, ``--format``, ``--kind``, ``--persistent``,
-        ``--update``, and ``--kind`` to a given argument parser.
+        ``--optimistic``, ``--format``, ``--add-only``, ``--persistent``, and
+        ``--dataset``.
 
         Call ``args.make_squirrel()`` on the arguments returned from
         :py:meth:`parse_args` to finally instantiate and configure the
@@ -309,8 +311,8 @@ class SquirrelArgumentParser(PyrockoArgumentParser):
         '''
         Set up command line options commonly used in squirrel queries.
 
-        This will add options ``--codes``, ``--tmin``, ``--tmax``, and
-        ``--time``.
+        This will add optional arguments ``--kinds``, ``--codes``, ``--tmin``,
+        ``--tmax``, and ``--time``.
 
         Once finished with parsing, the query arguments are available as
         ``args.squirrel_query`` on the arguments returned from
@@ -392,8 +394,8 @@ def add_squirrel_selection_arguments(parser):
     :py:class:`~pyrocko.squirrel.base.Squirrel` instance.
 
     This will  optional arguments ``--add``, ``--include``, ``--exclude``,
-    ``--optimistic``, ``--format``, ``--kind``, ``--persistent``, ``--update``,
-    and ``--kind`` to a given argument parser.
+    ``--optimistic``, ``--format``, ``--add-only``, ``--persistent``,
+    and ``--dataset`` to a given argument parser.
 
     Once finished with parsing, call
     :py:func:`squirrel_from_selection_arguments` to finally instantiate and
@@ -473,14 +475,6 @@ def add_squirrel_selection_arguments(parser):
              'selections can be used to speed up startup of Squirrel-based '
              'applications.')
 
-    group.add_argument(
-        '--update', '-u',
-        dest='update',
-        action='store_true',
-        default=False,
-        help='Allow adding paths and datasets to existing persistent '
-             'selection.')
-
     group.add_argument(
         '--dataset', '-d',
         dest='datasets',
@@ -510,45 +504,9 @@ def squirrel_from_selection_arguments(args):
         datasets and remote sources added.
 
     '''
-    from pyrocko.squirrel import base, dataset
+    from pyrocko.squirrel import base
 
-    datasets = [
-        dataset.read_dataset(dataset_path) for dataset_path in args.datasets]
-
-    persistents = [ds.persistent or '' for ds in datasets if ds.persistent]
-    if args.persistent:
-        persistent = args.persistent
-    elif persistents:
-        persistent = persistents[0]
-        if not all(p == persistents for p in persistents[1:]):
-            raise error.SquirrelError(
-                'Given datasets specify different `persistent` settings.')
-
-        if persistent:
-            logger.info(
-                'Persistent selection requested by dataset: %s' % persistent)
-        else:
-            persistent = None
-
-    else:
-        persistent = None
-
-    squirrel = base.Squirrel(persistent=persistent)
-
-    if persistent and not squirrel.is_new():
-        if not args.update:
-            logger.info(
-                'Using existing persistent selection: %s' % persistent)
-            if args.paths or datasets:
-                logger.info(
-                    'Avoiding dataset rescan. Use --update/-u to '
-                    'rescan or add items to existing persistent selection.')
-
-            return squirrel
-
-        else:
-            logger.info(
-                'Updating existing persistent selection: %s' % persistent)
+    squirrel = base.Squirrel(persistent=args.persistent)
 
     if args.paths:
         squirrel.add(
@@ -559,8 +517,8 @@ def squirrel_from_selection_arguments(args):
             include=args.include,
             exclude=args.exclude)
 
-    for ds in datasets:
-        squirrel.add_dataset(ds, check=args.check)
+    for dataset_path in args.datasets:
+        squirrel.add_dataset(dataset_path, check=args.check)
 
     return squirrel
 
@@ -569,7 +527,8 @@ def add_squirrel_query_arguments(parser, without=[]):
     '''
     Set up command line options commonly used in squirrel queries.
 
-    This will add options ``--codes``, ``--tmin``, ``--tmax``, and ``--time``.
+    This will add optional arguments ``--kinds``, ``--codes``, ``--tmin``,
+    ``--tmax``, and ``--time``.
 
     Once finished with parsing, call
     :py:func:`squirrel_query_from_arguments` to get the parsed values.
