@@ -153,11 +153,6 @@ except ImportError:
 
 logger = logging.getLogger('pyrocko.util')
 
-try:
-    import progressbar as progressbar_mod
-except ImportError:
-    from pyrocko import dummy_progressbar as progressbar_mod
-
 
 try:
     num_full = num.full
@@ -176,10 +171,6 @@ except AttributeError:
         return a
 
 
-def progressbar_module():
-    return progressbar_mod
-
-
 g_setup_logging_args = 'pyrocko', 'warning'
 
 
@@ -739,19 +730,28 @@ class BetterHelpFormatter(optparse.IndentedHelpFormatter):
             ['%*s%s' % (self.current_indent, '', line) for line in lines])
 
 
+class ProgressBar:
+    def __init__(self, label, n):
+        from pyrocko.progress import progress
+        self._context = progress.view()
+        self._context.__enter__()
+        self._task = progress.task(label, n)
+
+    def update(self, i):
+        self._task.update(i)
+
+    def finish(self):
+        self._task.done()
+        if self._context:
+            self._context.__exit__()
+            self._context = None
+
+
 def progressbar(label, maxval):
-    progressbar_mod = progressbar_module()
     if force_dummy_progressbar:
-        progressbar_mod = dummy_progressbar
+        return dummy_progressbar.ProgressBar(maxval=maxval).start()
 
-    widgets = [
-        label, ' ',
-        progressbar_mod.Bar(marker='-', left='[', right=']'), ' ',
-        progressbar_mod.Percentage(), ' ',
-        progressbar_mod.ETA()]
-
-    pbar = progressbar_mod.ProgressBar(widgets=widgets, maxval=maxval).start()
-    return pbar
+    return ProgressBar(label, maxval)
 
 
 def progress_beg(label):
@@ -1075,7 +1075,7 @@ def decimate_coeffs(q, n=None, ftype='iir'):
         if ftype == 'fir':
             n = 30
         elif ftype == 'fir-remez':
-            n = 40*q
+            n = 45*q
         else:
             n = 8
 
@@ -1092,7 +1092,7 @@ def decimate_coeffs(q, n=None, ftype='iir'):
         if (n, 1./q) not in coeffs:
             coeffs[n, 1./q] = signal.remez(
                 n+1, (0., .75/q, 1./q, 1.),
-                (1., 0.), Hz=2, weight=(1, 50))
+                (1., 0.), fs=2, weight=(1, 50))
         b = coeffs[n, 1./q]
         return b, [1.], n
 
@@ -1650,15 +1650,21 @@ def time_to_str(t, format='%Y-%m-%d %H:%M:%S.3FRAC'):
 
 
 tts = time_to_str
+_abbr_weekday = 'Mon Tue Wed Thu Fri Sat Sun'.split()
+_abbr_month = 'Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec'.split()
 
 
 def mystrftime(fmt=None, tt=None, milliseconds=0):
+    # Needed by Snuffler for the time axis. In other cases `time_to_str`
+    # should be used.
 
     if fmt is None:
         fmt = '%Y-%m-%d %H:%M:%S .%r'
 
-    if tt is None:
-        tt = time.time()
+    # Get these two locale independent, needed by Snuffler.
+    # Setting the locale seems to have no effect.
+    fmt = fmt.replace('%a', _abbr_weekday[tt.tm_wday])
+    fmt = fmt.replace('%b', _abbr_month[tt.tm_mon-1])
 
     fmt = fmt.replace('%r', '%03i' % int(round(milliseconds)))
     fmt = fmt.replace('%u', '%06i' % int(round(milliseconds*1000)))
@@ -1849,7 +1855,8 @@ def iter_select_files(
 
 
 def select_files(
-        paths, include=None, exclude=None, selector=None, show_progress=True):
+        paths, include=None, exclude=None, selector=None, show_progress=True,
+        regex=None):
 
     '''
     Recursively select files.
@@ -1859,6 +1866,7 @@ def select_files(
     :param exclude: pattern for conditional exclusion
     :param selector: callback for conditional inclusion
     :param show_progress: if True, indicate start and stop of processing
+    :param regex: alias for ``include`` (backwards compatibility)
     :returns: list of path names
 
     Recursively finds all files under given entry points ``paths``. If
@@ -1883,6 +1891,10 @@ def select_files(
             include=r'(?P<year>\\d\\d\\d\\d)\\.(?P<doy>\\d\\d\\d)$',
             selector=(lambda x: int(x.year) == 2009))
     '''
+    if regex is not None:
+        assert include is None
+        include = regex
+
     return list(iter_select_files(
         paths, include, exclude, selector, show_progress))
 
@@ -2613,7 +2625,7 @@ def consistency_check(list_of_tuples, message='values differ:'):
     if len(list_of_tuples) >= 2:
         if any(t[1:] != list_of_tuples[0][1:] for t in list_of_tuples[1:]):
             raise Inconsistency('%s\n' % message + '\n'.join(
-                '  %s: %s' % (t[0], ', '.join('%g' % x for x in t[1:]))
+                '  %s: %s' % (t[0], ', '.join(str(x) for x in t[1:]))
                 for t in list_of_tuples))
 
 
